@@ -2,6 +2,7 @@ package UUID;
 require 5.005;
 use strict;
 use warnings;
+use Carp 'croak';
 use Time::HiRes ();
 
 require Exporter;
@@ -10,15 +11,15 @@ require DynaLoader;
 use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.32_14';
+$VERSION = '0.33_01';
 
 %EXPORT_TAGS = (
     'all' => [qw(
         &clear &compare &copy &generate &generate_random &generate_time
-        &generate_v0 &generate_v1 &generate_v4 &generate_v6 &generate_v7
-        &is_null &parse &time &type &unparse &unparse_lower
-        &unparse_upper &uuid &uuid0 &uuid1 &uuid4 &uuid6 &uuid7 &variant
-        &version
+        &generate_v0 &generate_v1 &generate_v3 &generate_v4 &generate_v5
+        &generate_v6 &generate_v7 &is_null &parse &time &type &unparse
+        &unparse_lower &unparse_upper &uuid &uuid0 &uuid1 &uuid3 &uuid4
+        &uuid5 &uuid6 &uuid7 &variant &version
     )],
 );
 
@@ -29,9 +30,15 @@ bootstrap UUID $VERSION;
 sub import {
     for (my $i=scalar(@_)-1 ; $i>0 ; --$i) {
         my $v = $_[$i];
+        chomp $v;
         # :persist=FOO
-        if (length($v) > 9 and substr($v,0,9) eq ':persist=') {
-            _persist(substr($v, 9));
+        if (length($v) > 8 and substr($v,0,8) eq ':persist') {
+            my $arg = substr $v, 8;
+            if (length($arg) < 2 or substr($arg, 0, 1) ne '=') {
+                croak "Usage: :persist=FILE";
+            }
+            my $file = substr $arg, 1;
+            _persist($file);
             splice @_, $i, 1;
             next;
         }
@@ -47,6 +54,17 @@ sub import {
             splice @_, $i, 1;
             next;
         }
+        # :snap=N
+        if (length($v) > 5 and substr($v,0,5) eq ':snap') {
+            my $arg = substr $v, 5;
+            if (length($arg) < 2 or substr($arg, 0, 1) ne '=') {
+                croak "Usage: :snap=N";
+            }
+            my $val = substr $arg, 1;
+            _snap($val);
+            splice @_, $i, 1;
+            next;
+        }
     }
     goto &Exporter::import;
 }
@@ -62,22 +80,29 @@ UUID - Universally Unique Identifier library for Perl
 
 =head1 SYNOPSIS
 
+    # SIMPLE
     use UUID qw(uuid);    # see EXPORTS
-
     my $str = uuid();     # generate version 4 UUID string
 
-    $str = uuid();                    # new stringified UUID; prefer v4
-    $str = uuid1();                   # new stringified UUID; always v1
-    $str = uuid4();                   # new stringified UUID; always v4
-    $str = uuid6();                   # new stringified UUID; always v6
-    $str = uuid7();                   # new stringified UUID; always v7
+    # SPECIFIC
+    $str = uuid1();                   # new version 1 UUID string
+    $str = uuid4();                   # new version 4 UUID string
+    $str = uuid6();                   # new version 6 UUID string
+    $str = uuid7();                   # new version 7 UUID string
 
-    UUID::generate($bin);             # new binary UUID; prefer v4
-    UUID::generate_v1($bin);          # new binary UUID; always v1
-    UUID::generate_v4($bin);          # new binary UUID; always v4
-    UUID::generate_v6($bin);          # new binary UUID; always v6
-    UUID::generate_v7($bin);          # new binary UUID; always v7
+    # namespace is 'dns', 'url', 'oid', or 'x500', case-insensitive.
+    $str = uuid3(dns => 'www.example.com');
+    $str = uuid5(url => 'https://www.example.com/foo.html');
 
+    UUID::generate_v1($bin);          # new version 1 binary UUID
+    UUID::generate_v4($bin);          # new version 4 binary UUID
+    UUID::generate_v6($bin);          # new version 6 binary UUID
+    UUID::generate_v7($bin);          # new version 7 binary UUID
+
+    UUID::generate_v3($bin, dns => 'www.example.com');
+    UUID::generate_v5($bin, url => 'https://www.example.com/foo.txt');
+
+    UUID::generate($bin);             # alias for generate_v1()
     UUID::generate_time($bin);        # alias for generate_v1()
     UUID::generate_random($bin);      # alias for generate_v4()
 
@@ -111,11 +136,11 @@ system, and unique across all systems, and are compatible with those
 created by the Open Software Foundation (OSF) Distributed Computing
 Environment (DCE).
 
-All generated UUIDs are either version 1, 4, 6, or version 7. And all
-are variant 1, meaning compliant with the OSF DCE standard as described
-in RFC4122.
+All generated UUIDs are either version 1, 3, 4, 5, 6, or version 7. And
+all are variant 1, meaning compliant with the OSF DCE standard as
+described in RFC4122.
 
-Versions 6, 7, and 8 are not standardized. They are presented here as
+Versions 6 and 7 are not standardized. They are presented here as
 proposed in RFC4122bis, version 14, and may change in the future.
 RFC4122bis is noted to replace RFC4122, if approved.
 
@@ -189,11 +214,35 @@ is requested (see B<:mac> in B<EXPORTS>), a random address is used. The
 multicast bit of this address is set to avoid conflict with addresses
 returned from network cards.
 
+=head2 B<generate_v3(> I<$uuid>, I<NAMESPACE> => I<NAME> B<)>
+
+Generate a new version 3 binary UUID using the given namespace and name
+hashed through the MD5 algorithm.
+
+Namespace is one of "dns", "url", "oid", or "x500", and
+case-insensitive. It is used to select the namespace UUID to hash with
+the name.
+
+Name should be an entity from the given namespace, but can really be any
+text.
+
 =head2 B<generate_v4(> I<$uuid> B<)>
 
 Generates a new version 4 binary UUID using mostly random data. There
 are 6 bits used for the UUID format, leaving 122 bits for randomness.
 
+=head2 B<generate_v5(> I<$uuid>, I<NAMESPACE> => I<NAME> B<)>
+
+Generate a new version 5 binary UUID using the given namespace and name
+hashed through the SHA1 algorithm.
+
+Namespace is one of "dns", "url", "oid", or "x500", and
+case-insensitive. It is used to select the namespace UUID to hash with
+the name.
+
+Name should be an entity from the given namespace, but can really be any
+text.
+
 =head2 B<generate_v6(> I<$uuid> B<)>
 
 Generates a new version 6 binary UUID using the current time and the
@@ -272,10 +321,18 @@ Returns a new string format version 1 UUID. Functionally the equivalent
 of calling B<generate_v1()> then B<unparse()>, but throwing away the
 intermediate binary UUID.
 
+=head2 B<uuid3(NAMESPACE => NAME)>
+
+Same as B<uuid1()> but version 3. See B<generate_v3()>.
+
 =head2 B<uuid4()>
 
 Same as B<uuid1()> but version 4.
 
+=head2 B<uuid5(NAMESPACE => NAME)>
+
+Same as B<uuid1()> but version 5. See B<generate_v5()>.
+
 =head2 B<uuid6()>
 
 Same as B<uuid1()> but version 6.
